<?php
/*
Plugin Name: WooCommerce Video Product Tab
Plugin URI: http://www.sebs-studio.com/wp-plugins/woocommerce-video-product-tab
Description: Extends WooCommerce to allow you to add a Video to the Product page. An additional tab is added on the products page to allow customers to view a video.
Version: 1.2
Author: Sebs Studio (Sebastien)
Author URI: http://www.sebs-studio.com
License: GPL2
*/

/*  Copyright (C) 2012  Sebastien (email : sebastien@sebs-studio.com)

	This program is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 2
	of the License, or (at your option) any later version.
	
	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.
	
	You should have received a copy of the GNU General Public License
	along with this program; if not, write to the Free Software
	Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
*/


// Plugin Name.
define('wc_video_tab_plugin_name', 'WooCommerce Video Product Tab');

// Exit if accessed directly
if(!defined('ABSPATH')) exit;

// Required minimum version of WordPress.
if(!function_exists('woo_video_tab_min_required')){
	function woo_video_tab_min_required(){
		global $wp_version;
		$plugin = plugin_basename(__FILE__);
		$plugin_data = get_plugin_data(__FILE__, false);

		if(version_compare($wp_version, "3.3", "<")){
			if(is_plugin_active($plugin)){
				deactivate_plugins($plugin);
				wp_die("'".$plugin_data['Name']."' requires WordPress 3.3 or higher, and has been deactivated! Please upgrade WordPress and try again.<br /><br />Back to <a href='".admin_url()."'>WordPress Admin</a>.");
			}
		}
	}
	add_action('admin_init', 'woo_video_tab_min_required');
}

// Checks if the WooCommerce plugins is installed and active.
if(in_array('woocommerce/woocommerce.php', apply_filters('active_plugins', get_option('active_plugins')))){
	if(!class_exists('WooCommerce_Video_Product_Tab')){
		class WooCommerce_Video_Product_Tab{

			public static $plugin_prefix;
			public static $plugin_url;
			public static $plugin_path;
			public static $plugin_basefile;

			private $tab_data = false;

			/**
			 * Gets things started by adding an action to initialize this plugin once
			 * WooCommerce is known to be active and initialized
			 */
			public function __construct(){
				WooCommerce_Video_Product_Tab::$plugin_prefix = 'wc_video_tab_';
				WooCommerce_Video_Product_Tab::$plugin_basefile = plugin_basename(__FILE__);
				WooCommerce_Video_Product_Tab::$plugin_url = plugin_dir_url(WooCommerce_Video_Product_Tab::$plugin_basefile);
				WooCommerce_Video_Product_Tab::$plugin_path = trailingslashit(dirname(__FILE__));
				add_action('woocommerce_init', array(&$this, 'init'));
			}

			/**
			 * Init WooCommerce Video Product Tab extension once we know WooCommerce is active
			 */
			public function init(){
				// backend stuff
				add_filter('plugin_row_meta', array($this, 'add_support_link'), 10, 2);
				add_action('woocommerce_product_write_panel_tabs', array($this, 'product_write_panel_tab'));
				add_action('woocommerce_product_write_panels', array($this, 'product_write_panel'));
				add_action('woocommerce_process_product_meta', array($this, 'product_save_data'), 10, 2);
				// frontend stuff
				add_action('woocommerce_product_tabs', array($this, 'video_product_tabs'), 25);
				add_action('woocommerce_product_tab_panels', array($this, 'video_product_tabs_panel'), 25);
			}

			/**
			 * Add donation link to plugin page.
			 */
			public function add_support_link($links, $file){
				if(!current_user_can('install_plugins')){
					return $links;
				}
				if($file == WooCommerce_Video_Product_Tab::$plugin_basefile){
					$links[] = '<a href="http://www.sebs-studio.com/donation/" target="_blank">'.__('Donate').'</a>';
				}
				return $links;
			}

			/**
			 * Write the video tab on the product view page.
			 * In WooCommerce these are handled by templates.
			 */
			public function video_product_tabs(){
				global $product;

				if($this->product_has_video_tabs($product)){
					foreach($this->tab_data as $tab){
						echo "<li><a href=\"#{$tab['id']}\">".__('Video')."</a></li>";
					}
				}
			}

			/**
			 * Write the video tab panel on the product view page.
			 * In WooCommerce these are handled by templates.
			 */
			public function video_product_tabs_panel(){
				global $product;

				$embed = new WP_Embed(); // Since version 1.2

				if($this->product_has_video_tabs($product)){
					foreach($this->tab_data as $tab){
						echo '<div class="panel" id="'.$tab['id'].'">';
						echo '<h2>'.__("Video").'</h2>';
						//echo apply_filters('woocommerce_video_product_tab', $tab['video'], $tab['id']);
						echo $embed->autoembed(apply_filters('woocommerce_video_product_tab', $tab['video'], $tab['id'])); // Altered in version 1.2
						echo '</div>';
					}
				}
			}

			/**
			 * Lazy-load the product_tabs meta data, and return true if it exists,
			 * false otherwise
			 * 
			 * @return true if there is video tab data, false otherwise
			 */
			private function product_has_video_tabs($product){
				if($this->tab_data === false){
					$this->tab_data = maybe_unserialize(get_post_meta($product->id, 'woo_video_product_tab', true));
				}
				// tab must at least have a title to exist
				return !empty($this->tab_data) && !empty($this->tab_data[0]) && !empty($this->tab_data[0]['video']);
			}

			/**
			 * Adds a new tab to the Product Data postbox in the admin product interface
			 */
			public function product_write_panel_tab(){
				echo "<li><a style=\"color:#555555;line-height:16px;padding:9px;text-shadow:0 1px 1px #FFFFFF;\" href=\"#video_tab\">".__('Video')."</a></li>";
			}

			/**
			 * Adds the panel to the Product Data postbox in the product interface
			 */
			public function product_write_panel(){
				global $post;

				// Pull the video tab data out of the database
				$tab_data = maybe_unserialize(get_post_meta($post->ID, 'woo_video_product_tab', true));

				if(empty($tab_data)){
					$tab_data[] = array('video' => '');
				}

				// Display the video tab panel
				foreach($tab_data as $tab){
					echo '<div id="video_tab" class="panel woocommerce_options_panel">';
					$this->woocommerce_wp_textarea_input(array('id' => '_tab_video', 'label' => __('Embed Code'), 'placeholder' => __('Place your video embed code here.'), 'value' => $tab['video'], 'style' => 'width:70%;height:21.5em;'));
					echo '</div>';
				}
			}

			private function woocommerce_wp_textarea_input($field){
				global $thepostid, $post;

				if(!$thepostid) $thepostid = $post->ID;
				if(!isset($field['placeholder'])) $field['placeholder'] = '';
				if(!isset($field['class'])) $field['class'] = 'short';
				if(!isset($field['value'])) $field['value'] = get_post_meta($thepostid, $field['id'], true);

				echo '<p class="form-field '.$field['id'].'_field"><label for="'.$field['id'].'">'.$field['label'].'</label><textarea class="'.$field['class'].'" name="'.$field['id'].'" id="'.$field['id'].'" placeholder="'.$field['placeholder'].'" rows="2" cols="20"'.(isset($field['style']) ? ' style="'.$field['style'].'"' : '').'">'.esc_textarea( $field['value']).'</textarea>';

				if(isset($field['description']) && $field['description']) echo '<span class="description">' .$field['description'] . '</span>';

				echo '</p>';
			}

			/**
			 * Saves the data inputed into the product boxes, as post meta data
			 * identified by the name 'woo_video_product_tab'
			 * 
			 * @param int $post_id the post (product) identifier
			 * @param stdClass $post the post (product)
			 */
			public function product_save_data($post_id, $post){

				$tab_video = stripslashes($_POST['_tab_video']);

				if(empty($tab_video) && get_post_meta($post_id, 'woo_video_product_tab', true)){
					// clean up if the video tabs are removed
					delete_post_meta($post_id, 'woo_video_product_tab');
				}
				elseif(!empty($tab_video)){
					$tab_data = array();

					$tab_id = '';
					$tab_title = 'Video';
					// convert the tab title into an id string
					$tab_id = strtolower($tab_title);
					$tab_id = preg_replace("/[^\w\s]/",'',$tab_id); // remove non-alphas, numbers, underscores or whitespace 
					$tab_id = preg_replace("/_+/", ' ', $tab_id); // replace all underscores with single spaces
					$tab_id = preg_replace("/\s+/", '-', $tab_id); // replace all multiple spaces with single dashes
					$tab_id = 'tab-'.$tab_id; // prepend with 'tab-' string

					// save the data to the database
					$tab_data[] = array('title' => $tab_title, 'id' => $tab_id, 'video' => $tab_video);
					update_post_meta($post_id, 'woo_video_product_tab', $tab_data);
				}
			}
		}
	}

	/* 
	 * Instantiate plugin class and add it to the set of globals.
	 */
	$woocommerce_video_tab = new WooCommerce_Video_Product_Tab();
}
else{
	add_action('admin_notices', 'wc_video_tab_error_notice');
	function wc_video_tab_error_notice(){
		global $current_screen;
		if($current_screen->parent_base == 'plugins'){
			echo '<div class="error"><p>'.__(wc_video_tab_plugin_name.' requires <a href="http://www.woothemes.com/woocommerce/" target="_blank">WooCommerce</a> to be activated in order to work. Please install and activate <a href="'.admin_url('plugin-install.php?tab=search&type=term&s=WooCommerce').'" target="_blank">WooCommerce</a> first.').'</p></div>';
		}
	}
}
?>